import vtk
heightFactor=0.1

# Texture 
tex_reader = vtk.vtkBMPReader()
tex_reader.SetFileName("./masonry.bmp")

tex = vtk.vtkTexture()
tex.SetInputConnection(tex_reader.GetOutputPort())
tex.InterpolateOn()
tex.RepeatOff()

# Height field
reader = vtk.vtkImageReader2()
reader.SetFileName("./dem30.raw")
reader.SetDataByteOrderToBigEndian()
reader.SetDataScalarTypeToFloat()
reader.SetDataExtent(0, 266, 0, 266, 0,0)

geom = vtk.vtkImageDataGeometryFilter()
geom.SetInputConnection(reader.GetOutputPort())

warp = vtk.vtkWarpScalar()
warp.SetInputConnection(geom.GetOutputPort())
warp.SetScaleFactor(heightFactor)

normals = vtk.vtkPolyDataNormals()
normals.SetInputConnection(warp.GetOutputPort())
normals.SetFeatureAngle(80)

# mapper, actor and rendering
mapper = vtk.vtkPolyDataMapper()
mapper.SetInputConnection(normals.GetOutputPort())
mapper.ScalarVisibilityOff()

actor = vtk.vtkActor()
actor.SetMapper(mapper)
actor.SetTexture(tex)

ren = vtk.vtkRenderer()
ren.AddActor(actor)
ren.SetBackground(1, 1, 1)

renWin = vtk.vtkRenderWindow()
renWin.AddRenderer(ren)
renWin.SetSize(300, 300)

iren = vtk.vtkRenderWindowInteractor()
iren.SetRenderWindow(renWin)

iren.Initialize()
iren.Render()
iren.Start()
